# 赞助

首先说明，由于我只是将 B 站的视频搬运到你的电脑上，是一件很简单的事情，请把最大的感激给予平台以及创作者。

如果你想支持我的话，在 [GitHub 项目主页](https://github.com/yutto-dev/yutto)给予我一个 「Star」 就是对我的最大鼓励。

此外，如果你想给予 Nyakku 一定资金支持以激励 Nyakku 的开发的话，你可以通过以下方式进行

## 一次性赞助

你可以通过[支付宝](https://img.nyakku.moe/sponsor/alipay.png)或者[微信](https://img.nyakku.moe/sponsor/wechat.png)来为 Nyakku 提供一笔开发资金。

## 周期性赞助

你可以通过 [Patreon](https://www.patreon.com/SigureMo) 或者[爱发电](https://afdian.net/@siguremo)来为 Nyakku 提供每月的资金支持，以激励 Nyakku 创作更多有趣、实用的开源项目。

你的任何金额的赞助我都会无比珍惜，我会在[项目致谢](./guide/thanks)中标注你的 GitHub ID（需要在赞助时备注你的 GitHub ID，如果有资助后忘记留 ID 的可以联系我～）。
